@@ -1,14 +1,12 @@
 use libnotcurses_sys::*;
 
-fn main() {
+fn main() -> NcResult<()> {
     unsafe {
-        let nc = Notcurses::new();
-
-        // use standard plane
+        let nc = Notcurses::new()?;
         let stdplane = notcurses_stdplane(nc);
 
         for ch in "Initializing cells...".chars() {
-            let cell = NcCell::with_7bitchar(ch);
+            let cell = NcCell::with_char7b(ch);
             sleep![60];
             ncplane_putc(&mut *stdplane, &cell);
             let _ = notcurses_render(nc);
@@ -17,4 +15,5 @@ fn main() {
 
         notcurses_stop(nc);
     }
+    Ok(())
 }
