@@ -13,12 +13,13 @@
 //! ```rust
 //! use libnotcurses_sys::*;
 //!
-//! fn main() {
-//!     let nc = Notcurses::without_altscreen();
+//! fn main() -> NcResult<()> {
+//!     let nc = Notcurses::without_altscreen()?;
 //!     let plane = nc.stdplane();
 //!     plane.putstr("hello world");
 //!     nc.render();
-//!     nc.stop();
+//!     nc.stop()?;
+//!     Ok(())
 //! }
 //! ```
 //!
@@ -37,8 +38,8 @@
 //!
 //! fn main() {
 //!     let options = NotcursesOptions::with_flags(NCOPTION_NO_ALTERNATE_SCREEN);
-//!     let nc = Notcurses::with_options(&options);
 //!     unsafe {
+//!         let nc = notcurses_init(&options, core::ptr::null_mut());
 //!         let plane = notcurses_stdplane(nc);
 //!         ncplane_putstr(&mut *plane, "hello world");
 //!         notcurses_render(nc);
@@ -75,25 +76,24 @@
 //! ## Limitations of this library
 //!
 //! There are several common patterns in Rust that this library doesn't employ,
-//! and focuses instead on remaining at a very close distance to the C API.
+//! and focuses instead on remaining at a closer distance to the C API.
 //!
 //! 1. There are no Drop trait implementations, therefore you must manually stop
 //! each context before it goes out of scope ([Notcurses], [NcDirect]), and
 //! should manually destroy [NcPlane]s, [NcMenu]s… when no longer needed.
 //!
-//! 2. Instead of handling errors with `Result` (as customary in Rust),
-//!   several functions return an [NcResult] with a value of [NCRESULT_ERR],
-//!   (as customary in C), or [NCRESULT_OK].
+//! 2. The C style functions handle errors by the means of returning an i32 value
+//! aliased to [NcIntResult]. But the Rust style methods handle errors more
+//! idiomatically using [NcResult] and [NcError].
 //!
-//! The [notcurses]() crate overcomes this limitations by using higher level
-//! abstractions, while pulling itself apart from the C API, in ways this
+//! The [notcurses]() crate will use higher level abstractions in ways this
 //! library can not do.
 //!
 //! ### Things this library does do
 //!
 //! - Type aliases every underlying C type to leverage type checking.
 //! - Renames types to enforce regularity and consistency. (e.g. [NcCell])
-//! - Has handy macros like [sleep], [rsleep] & [cstring].
+//! - Has handy macros for common tasks like [sleep!], [cstring!] & [error!].
 //!
 //! ## The `notcurses` C API docs
 //!
@@ -112,39 +112,45 @@ mod bindings;
 #[doc(inline)]
 pub use bindings::*;
 
+mod r#box;
 mod cells;
 mod channel;
+mod dimension;
 mod direct;
 mod error;
+mod fade;
 mod file;
 mod input;
-mod key;
-mod keycodes;
 mod macros;
 mod metric;
 mod notcurses;
 mod palette;
 mod pixel;
 mod plane;
+mod resizecb;
+mod signal;
 mod stats;
 mod time;
 mod visual;
 mod widgets;
 
+pub use crate::input::*;
 pub use cells::*;
 pub use channel::*;
+pub use dimension::*;
 pub use direct::*;
 pub use error::*;
+pub use fade::*;
 pub use file::*;
-pub use input::*;
-pub use key::*;
-pub use keycodes::*;
 pub use macros::*;
 pub use metric::*;
 pub use notcurses::*;
 pub use palette::*;
 pub use pixel::*;
 pub use plane::*;
+pub use r#box::*;
+pub use resizecb::*;
+pub use signal::*;
 pub use stats::*;
 pub use time::*;
 pub use visual::*;
