@@ -1,69 +1,77 @@
 //! `Notcurses`
 
-// functions already exported by bindgen : 39
+// functions already exported by bindgen : 41
 // ------------------------------------------
-// (#) unit tests: 10 / 29
+// (#) test: 10
+// (W) wrap: 40 / 1
 // ------------------------------------------
-//   notcurses_at_yx
-//   notcurses_bottom
-// # notcurses_canchangecolor
-// # notcurses_canfade
-// # notcurses_canopen_images
-// # notcurses_canopen_videos
-// # notcurses_cansixel
-// # notcurses_cantruecolor
-// # notcurses_canutf8
-//   notcurses_cursor_disable
-//   notcurses_cursor_enable
-// # notcurses_debug
-// # notcurses_drop_planes
-//   notcurses_getc
-// # notcurses_init
-//   notcurses_inputready_fd
-//   notcurses_lex_blitter
-//   notcurses_lex_margins
-//   notcurses_lex_scalemode
-//   notcurses_mouse_disable
-//   notcurses_mouse_enable
-//   notcurses_palette_size
-//   notcurses_refresh
-//   notcurses_render
-//   notcurses_render_to_buffer
-//   notcurses_render_to_file
-//   notcurses_stats
-//   notcurses_stats_alloc
-//   notcurses_stats_reset
-//   notcurses_stdplane
-//   notcurses_stdplane_const
-// # notcurses_stop
-//   notcurses_str_blitter
-//   notcurses_str_scalemode
-//   notcurses_supported_styles
-//   notcurses_top
-//   notcurses_ucs32_to_utf8
-//   notcurses_version
-//   notcurses_version_components
+//W  notcurses_at_yx
+//W  notcurses_bottom
+//W# notcurses_canchangecolor
+//W# notcurses_canfade
+//W# notcurses_canopen_images
+//W# notcurses_canopen_videos
+//W# notcurses_cansixel
+//W# notcurses_cantruecolor
+//W# notcurses_canutf8
+//W  notcurses_cursor_disable
+//W  notcurses_cursor_enable
+//W# notcurses_debug
+//W# notcurses_drop_planes
+//W  notcurses_getc
+//W# notcurses_init
+//W  notcurses_inputready_fd
+//W  notcurses_lex_blitter
+//W  notcurses_lex_margins
+//W  notcurses_lex_scalemode
+//W  notcurses_linesigs_disable
+//W  notcurses_linesigs_enable
+//W  notcurses_mouse_disable
+//W  notcurses_mouse_enable
+//W  notcurses_palette_size
+//W  notcurses_refresh
+//W  notcurses_render
+//W  notcurses_render_to_buffer
+//W  notcurses_render_to_file
+//W  notcurses_stats
+//W  notcurses_stats_alloc
+//W  notcurses_stats_reset
+//W  notcurses_stdplane
+//W  notcurses_stdplane_const
+//W# notcurses_stop
+//W  notcurses_str_blitter
+//W  notcurses_str_scalemode
+//W  notcurses_supported_styles
+//W  notcurses_top
+//~  notcurses_ucs32_to_utf8 (not needed in rust)
+//W# notcurses_version
+//W  notcurses_version_components
 //
 // functions manually reimplemented: 6
 // -----------------------------------------
-// (+) implement : 6 / 0
-// (#) unit tests: 0 / 6
+// (+) done: 6 / 0
+// (#) test: 0
+// (W) wrap: 4 / 0
 // -----------------------------------------
-// # notcurses_align
-// + notcurses_getc_blocking
-// + notcurses_getc_nblock
-// + notcurses_stddim_yx
-// + notcurses_stddim_yx_const
-// + notcurses_term_dim_yx
+//W# notcurses_align
+//W+ notcurses_getc_blocking
+//W+ notcurses_getc_nblock
+//W+ notcurses_stddim_yx
+//W+ notcurses_stddim_yx_const
+//W+ notcurses_term_dim_yx
 
 #[cfg(test)]
 mod test;
 
+mod helpers;
 mod methods;
 mod reimplemented;
+
+#[allow(unused_imports)]
+pub(crate) use helpers::*;
 pub use reimplemented::*;
 
-/// The main struct of the (full mode) TUI library
+/// The main struct of the TUI library (full mode)
 ///
 /// Notcurses builds atop the terminfo abstraction layer to
 /// provide reasonably portable vivid character displays.
@@ -102,16 +110,17 @@ pub const NCOPTION_NO_FONT_CHANGES: u64 = crate::bindings::ffi::NCOPTION_NO_FONT
 
 /// Do not handle SIG{ING, SEGV, ABRT, QUIT}
 ///
-/// We typically install a signal handler for SIG{INT, SEGV, ABRT, QUIT} that
-/// restores the screen, and then calls the old signal handler. Set to inhibit
-/// registration of these signal handlers.
+/// A signal handler will usually be installed for SIGINT, SIGQUIT, SIGSEGV,
+/// SIGTERM, and SIGABRT, cleaning up the terminal on such exceptions.
+/// With this flag, the handler will not be installed.
 pub const NCOPTION_NO_QUIT_SIGHANDLERS: u64 =
     crate::bindings::ffi::NCOPTION_NO_QUIT_SIGHANDLERS as u64;
 
 /// Do not handle SIGWINCH
 ///
-/// We typically install a signal handler for SIGWINCH that generates a resize
-/// event in the notcurses_getc() queue. Set to inhibit this handler
+/// A signal handler will usually be installed for SIGWINCH, resulting in
+/// NCKEY_RESIZE events being generated on input.
+/// With this flag, the handler will not be installed.
 pub const NCOPTION_NO_WINCH_SIGHANDLER: u64 =
     crate::bindings::ffi::NCOPTION_NO_WINCH_SIGHANDLER as u64;
 
@@ -167,3 +176,28 @@ pub const NCLOGLEVEL_VERBOSE: NcLogLevel = crate::bindings::ffi::ncloglevel_e_NC
 
 /// you probably don't want what's happening to happen
 pub const NCLOGLEVEL_WARNING: NcLogLevel = crate::bindings::ffi::ncloglevel_e_NCLOGLEVEL_WARNING;
+
+// NcAlign -- ------------------------------------------------------------------
+
+/// Alignment within a plane or terminal.
+/// Left/right-justified, or centered.
+///
+/// ## Defined constants
+///
+/// - [NCALIGN_UNALIGNED]
+/// - [NCALIGN_LEFT]
+/// - [NCALIGN_CENTER]
+/// - [NCALIGN_RIGHT]
+pub type NcAlign = crate::bindings::ffi::ncalign_e;
+
+/// Left alignment within an [`NcPlane`][crate::NcPlane] or terminal.
+pub const NCALIGN_LEFT: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_LEFT;
+
+/// Right alignment within an [`NcPlane`][crate::NcPlane] or terminal.
+pub const NCALIGN_RIGHT: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_RIGHT;
+
+/// Center alignment within an [`NcPlane`][crate::NcPlane] or terminal.
+pub const NCALIGN_CENTER: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_CENTER;
+
+/// Do not align an [`NcPlane`][crate::NcPlane] or terminal.
+pub const NCALIGN_UNALIGNED: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_UNALIGNED;
