@@ -3,17 +3,20 @@
 use serial_test::serial;
 use std::io::Read;
 
-use crate::{notcurses_stop, NcFile, Notcurses};
+use crate::{notcurses_init_test, notcurses_stop, NcFile, NCRESULT_MAX};
 
 #[test]
 #[serial]
 fn notcurses_align() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         assert_eq![0, crate::notcurses_align(30, crate::NCALIGN_LEFT, 20)];
         assert_eq![5, crate::notcurses_align(30, crate::NCALIGN_CENTER, 20)];
         assert_eq![10, crate::notcurses_align(30, crate::NCALIGN_RIGHT, 20)];
-        assert_eq![10, crate::notcurses_align(30, crate::NCALIGN_UNALIGNED, 20)];
+        assert_eq![
+            -NCRESULT_MAX,
+            crate::notcurses_align(30, crate::NCALIGN_UNALIGNED, 20)
+        ];
         notcurses_stop(nc);
     }
 }
@@ -22,7 +25,7 @@ fn notcurses_align() {
 #[serial]
 fn notcurses_canchangecolor() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let res = crate::notcurses_canchangecolor(nc);
         notcurses_stop(nc);
         print!("[{}] ", res);
@@ -33,7 +36,7 @@ fn notcurses_canchangecolor() {
 #[serial]
 fn notcurses_canfade() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let res = crate::notcurses_canfade(nc);
         notcurses_stop(nc);
         print!("[{}] ", res);
@@ -44,7 +47,7 @@ fn notcurses_canfade() {
 #[serial]
 fn notcurses_canopen_images() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let res = crate::notcurses_canopen_images(nc);
         notcurses_stop(nc);
         print!("[{}] ", res);
@@ -55,7 +58,7 @@ fn notcurses_canopen_images() {
 #[serial]
 fn notcurses_canopen_videos() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let res = crate::notcurses_canopen_videos(nc);
         notcurses_stop(nc);
         print!("[{}] ", res);
@@ -66,7 +69,7 @@ fn notcurses_canopen_videos() {
 #[serial]
 fn notcurses_cansixel() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let res = crate::notcurses_cansixel(nc);
         notcurses_stop(nc);
         print!("[{}] ", res);
@@ -77,7 +80,7 @@ fn notcurses_cansixel() {
 #[serial]
 fn notcurses_cantruecolor() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let res = crate::notcurses_cantruecolor(nc);
         notcurses_stop(nc);
         print!("[{}] ", res);
@@ -88,7 +91,7 @@ fn notcurses_cantruecolor() {
 #[serial]
 fn notcurses_canutf8() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let res = crate::notcurses_canutf8(nc);
         notcurses_stop(nc);
         print!("[{}] ", res);
@@ -99,10 +102,10 @@ fn notcurses_canutf8() {
 #[serial]
 fn notcurses_drop_planes() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let stdplane = crate::notcurses_stdplane(nc);
-        let plane1 = crate::NcPlane::new_bound(&mut *stdplane, 0, 0, 10, 10);
-        let _plane2 = crate::NcPlane::new_bound(&mut *plane1, 0, 0, 10, 10);
+        let plane1 = crate::ncplane_new_bound_test(&mut *stdplane, 0, 0, 10, 10);
+        let _plane2 = crate::ncplane_new_bound_test(plane1, 0, 0, 10, 10);
 
         crate::notcurses_drop_planes(nc);
         // TODO: CHECK that planes are really dropped.
@@ -113,9 +116,9 @@ fn notcurses_drop_planes() {
 
 #[test]
 #[serial]
-fn notcurses_init() {
+fn notcurses_initialization() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         assert![nc as *mut _ != core::ptr::null_mut()];
         notcurses_stop(nc);
     }
@@ -127,7 +130,7 @@ fn notcurses_init() {
 // FIXME: always return null
 fn notcurses_at_yx() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let mut sm = 0;
         let mut ch = 0;
         let res = crate::notcurses_at_yx(nc, 0, 0, &mut sm, &mut ch);
@@ -142,7 +145,7 @@ fn notcurses_at_yx() {
 #[serial]
 fn notcurses_debug() {
     unsafe {
-        let nc = Notcurses::new();
+        let nc = notcurses_init_test();
         let mut _p: *mut i8 = &mut 0;
         let mut _size: *mut usize = &mut 0;
         let mut file = NcFile::from_libc(libc::open_memstream(&mut _p, _size));
@@ -158,3 +161,12 @@ fn notcurses_debug() {
         assert_eq![&string1[0..string2.len()], &string2[..]];
     }
 }
+
+#[test]
+#[serial]
+// TODO test version_components
+fn notcurses_version() {
+    let c_str = unsafe { crate::notcurses_version() };
+    assert!(!c_str.is_null());
+    print!("v{} ", crate::rstring![c_str]);
+}
