@@ -1,160 +1,158 @@
 //! `NcPlane`
 
-// functions already exported by bindgen : 105
-// ------------------------------------------
-// (#) 13 / 92 unit tests
-// (W) 1 wrapped as a method or function
-// ------------------------------------------
-//   ncpile_bottom
-// # ncpile_create
-//   ncpile_rasterize
-//   ncpile_render
-//   ncpile_top
-//   ncplane_above
-//   ncplane_at_cursor
-//   ncplane_at_yx
-//   ncplane_base
-//   ncplane_below
-//   ncplane_box
-//   ncplane_center_abs
-// # ncplane_channels
-//   ncplane_contents
-//   ncplane_create
-// # ncplane_cursor_move_yx
+// functions already exported by bindgen : 102
+// -------------------------------------------
+// (X) wont:  6
+// (#) test: 13
+// (W) wrap: 77
+// -------------------------------------------
+//W  ncpile_bottom
+//W# ncpile_create
+//W  ncpile_rasterize
+//W  ncpile_render
+//W  ncpile_top
+//W  ncplane_above
+//W  ncplane_at_cursor
+//W  ncplane_at_yx
+//W  ncplane_base
+//W  ncplane_below
+//W  ncplane_box
+//W  ncplane_center_abs
+//W# ncplane_channels
+//W  ncplane_contents
+//W  ncplane_create
+//W# ncplane_cursor_move_yx
 //W# ncplane_cursor_yx
-//   ncplane_destroy
+//W  ncplane_destroy
 //W# ncplane_dim_yx
-//   ncplane_dup
-// # ncplane_erase
-//   ncplane_fadein
-//   ncplane_fadein_iteration
-//   ncplane_fadeout
-//   ncplane_fadeout_iteration
-//   ncplane_format
-//   ncplane_gradient
-//   ncplane_greyscale
-//   ncplane_highgradient
-//   ncplane_highgradient_sized
+//W  ncplane_dup
+//W# ncplane_erase
+//W  ncplane_fadein
+//W  ncplane_fadein_iteration
+//W  ncplane_fadeout
+//W  ncplane_fadeout_iteration
+//W  ncplane_format
+//W  ncplane_gradient
+//W  ncplane_greyscale
+//W  ncplane_highgradient
+//W  ncplane_highgradient_sized
 //   ncplane_hline_interp
-// # ncplane_home
-//   ncplane_mergedown
-//   ncplane_mergedown_simple
-//   ncplane_move_above
-//   ncplane_move_below
-//   ncplane_move_bottom
-//   ncplane_move_top
-//   ncplane_move_yx
-//   ncplane_new
-// # ncplane_notcurses
-// # ncplane_notcurses_const
-//   ncplane_off_styles
-//   ncplane_on_styles
-//   ncplane_parent
-//   ncplane_parent_const
+//W# ncplane_home
+//W  ncplane_mergedown
+//W  ncplane_mergedown_simple
+//W  ncplane_move_above
+//W  ncplane_move_below
+//W  ncplane_move_bottom
+//W  ncplane_move_top
+//W  ncplane_move_yx
+//W# ncplane_notcurses
+//W# ncplane_notcurses_const
+//W  ncplane_off_styles
+//W  ncplane_on_styles
+//W  ncplane_parent
+//W  ncplane_parent_const
 //   ncplane_polyfill_yx
-//   ncplane_pulse
+//W  ncplane_pulse
 //   ncplane_putchar_stained
 //   ncplane_putc_yx
-//   ncplane_putegc_stained
-//   ncplane_putegc_yx
+// X ncplane_putegc_stained            // unneeded
+// X ncplane_putegc_yx                 // unneeded
 //   ncplane_putnstr_aligned
 //   ncplane_putnstr_yx
 //   ncplane_putstr_aligned
 //   ncplane_putstr_stained
 //   ncplane_putstr_yx
 //   ncplane_puttext
-//   ncplane_putwegc_stained
-//   ncplane_putwstr_stained
+// X ncplane_putwegc_stained           // unneeded
+// X ncplane_putwstr_stained           // unneeded
 //   ncplane_qrcode
-//   ncplane_reparent
-//   ncplane_reparent_family
-// # ncplane_resize
-//   ncplane_resizecb
-//   ncplane_resize_realign
+//W  ncplane_reparent
+//W  ncplane_reparent_family
+//W# ncplane_resize
+//W  ncplane_resizecb
+//W  ncplane_resize_realign
 //   ncplane_rgba
-//   ncplane_rotate_ccw
-//   ncplane_rotate_cw
-//   ncplane_set_base
-//   ncplane_set_base_cell
-// # ncplane_set_bchannel
-//   ncplane_set_bg_alpha
-//   ncplane_set_bg_default
-//   ncplane_set_bg_palindex
-//   ncplane_set_bg_rgb
-//   ncplane_set_bg_rgb8
-//   ncplane_set_bg_rgb8_clipped
-// # ncplane_set_channels
-// # ncplane_set_fchannel
-//   ncplane_set_fg_alpha
-//   ncplane_set_fg_default
-//   ncplane_set_fg_palindex
-//   ncplane_set_fg_rgb
-//   ncplane_set_fg_rgb8
-//   ncplane_set_fg_rgb8_clipped
-//   ncplane_set_resizecb
-//   ncplane_set_scrolling
-//   ncplane_set_styles
+//W  ncplane_rotate_ccw
+//W  ncplane_rotate_cw
+//W  ncplane_set_base
+//W  ncplane_set_base_cell
+//W# ncplane_set_bchannel
+//W  ncplane_set_bg_alpha
+//W  ncplane_set_bg_default
+//W  ncplane_set_bg_palindex
+//W  ncplane_set_bg_rgb
+//W  ncplane_set_bg_rgb8
+// X ncplane_set_bg_rgb8_clipped       // unneeded
+//W# ncplane_set_channels
+//W# ncplane_set_fchannel
+//W  ncplane_set_fg_alpha
+//W  ncplane_set_fg_default
+//W  ncplane_set_fg_palindex
+//W  ncplane_set_fg_rgb
+//W  ncplane_set_fg_rgb8
+// X ncplane_set_fg_rgb8_clipped       // unneeded
+//W  ncplane_set_resizecb
+//W  ncplane_set_scrolling
+//W  ncplane_set_styles
 //   ncplane_set_userptr
-//   ncplane_stain
-//   ncplane_styles
-//   ncplane_styles_off
-//   ncplane_styles_on
-//   ncplane_styles_set
-//   ncplane_translate
-//   ncplane_translate_abs
+//W  ncplane_stain
+//W  ncplane_styles
+//W  ncplane_translate
+//W  ncplane_translate_abs
 //   ncplane_userptr
 //   ncplane_vline_interp
 //   ncplane_vprintf_aligned
 //   ncplane_vprintf_stained
 //   ncplane_vprintf_yx
-//   ncplane_x
-//   ncplane_y
-//   ncplane_yx
+//W  ncplane_x
+//W  ncplane_y
+//W  ncplane_yx
 //
-// functions manually reimplemented: 42
+// functions manually reimplemented: 41
 // ------------------------------------------
-// (X) wont:  8
+// (X) wont:  9
 // (+) done: 34 / 0
-// (#) test:  5 / 29
+// (W) wrap: 24
+// (#) test:  5
 // ------------------------------------------
-// + ncplane_align
-// + ncplane_at_cursor_cell
-// + ncplane_at_yx_cell
-// + ncplane_bchannel
-// + ncplane_bg_alpha
-// # ncplane_bg_default_p
-// + ncplane_bg_rgb
-// + ncplane_bg_rgb8
-// + ncplane_box_sized
+//W+ ncplane_align
+//W+ ncplane_at_cursor_cell
+//W+ ncplane_at_yx_cell
+//W+ ncplane_bchannel
+//W+ ncplane_bg_alpha
+//W# ncplane_bg_default_p
+//W+ ncplane_bg_rgb
+//W+ ncplane_bg_rgb8
+//W+ ncplane_box_sized
 //W# ncplane_dim_x
 //W# ncplane_dim_y
-// + ncplane_double_box
-// + ncplane_double_box_sized
-// + ncplane_fchannel
-// + ncplane_fg_alpha
-// # ncplane_fg_default_p
-// + ncplane_fg_rgb
-// + ncplane_fg_rgb8
-// + ncplane_gradient_sized       // u64|u32 https://github.com/dankamongmen/notcurses/issues/920
+//W+ ncplane_double_box
+//W+ ncplane_double_box_sized
+//W+ ncplane_fchannel
+//W+ ncplane_fg_alpha
+//W# ncplane_fg_default_p
+//W+ ncplane_fg_rgb
+//W+ ncplane_fg_rgb8
+//W+ ncplane_gradient_sized
 // + ncplane_hline
-// + ncplane_perimeter
-// + ncplane_perimeter_double
-// + ncplane_perimeter_rounded
+//W+ ncplane_perimeter
+//W+ ncplane_perimeter_double
+//W+ ncplane_perimeter_rounded
 // + ncplane_putc
 // + ncplane_putchar
 // + ncplane_putchar_yx
-// + ncplane_putegc
+// X ncplane_putegc                    // unneeded
 // + ncplane_putnstr
 //W+ ncplane_putstr
-// X ncplane_putwc                // I don't think these will be needed from Rust. See:
-// X ncplane_putwc_stained
-// X ncplane_putwc_yx             // https://locka99.gitbooks.io/a-guide-to-porting-c-to-rust/content/features_of_rust/strings.html
-// X ncplane_putwegc              //
-// X ncplane_putwegc_yx           //
-// X ncplane_putwstr              //
-// X ncplane_putwstr_aligned      //
-// X ncplane_putwstr_yx           //
-// # ncplane_resize_simple
+// X ncplane_putwc                     // unneeded
+// X ncplane_putwc_stained             // unneeded
+// X ncplane_putwc_yx                  // unneeded
+// X ncplane_putwegc                   // unneeded
+// X ncplane_putwegc_yx                // unneeded
+// X ncplane_putwstr                   // unneeded
+// X ncplane_putwstr_aligned           // unneeded
+// X ncplane_putwstr_yx                // unneeded
+//W# ncplane_resize_simple
 // + ncplane_rounded_box
 // + ncplane_rounded_box_sized
 // + ncplane_vline
@@ -165,8 +163,12 @@
 #[cfg(test)]
 mod test;
 
+mod helpers;
 mod methods;
 mod reimplemented;
+
+#[allow(unused_imports)]
+pub(crate) use helpers::*;
 pub use reimplemented::*;
 
 // NcPlane
@@ -179,7 +181,7 @@ pub use reimplemented::*;
 /// `type in C: ncplane (struct)`
 ///
 ///
-/// ## Piles
+/// # Piles
 ///
 /// A single notcurses context is made up of one or more piles.
 ///
@@ -209,6 +211,23 @@ pub use reimplemented::*;
 /// pile's z-axis. When ncplane_reparent_family() is used, all planes bound to
 /// the reparented plane are moved along with it. Their relative z-order is maintained.
 ///
+///
+/// # Methods & Associated Functions
+///
+/// - [Constructors & Destructors](#ncplane-constructors-and-destructors)
+///
+/// Methods:
+/// - [`NcAlphaBits`](#ncplane-methods-ncalphabits)
+/// - [`NcChannel` & `NcChannelPair`](#ncplane-methods-ncchannel)
+/// - [`NcColor`, `NcRgb` & default color](#ncplane-methods-nccolor-ncrgb--default-color)
+/// - [`NcStyleMask` & `NcPaletteIndex`](#ncplane-methods-ncstylemask--paletteindex)
+/// - [`NcCell` & `NcEgc`](#ncplane-methods-nccell--ncegc)
+/// - [cursor](#ncplane-methods-cursor)
+/// - [`NcPlane` & `Notcurses`](#ncplane-methods-ncplane--notcurses)
+/// - [boxes & perimeters](#ncplane-methods-boxes--perimeters)
+/// - [Size, position & alignment](#ncplane-methods-size-position--alignment)
+/// - [fading, gradients & greyscale](#ncplane-methods-fading-gradients--greyscale)
+///
 pub type NcPlane = crate::bindings::ffi::ncplane;
 
 /// Options struct for [`NcPlane`]
@@ -227,22 +246,6 @@ pub type NcFdPlane = crate::bindings::ffi::ncfdplane;
 /// `type in C: ncplane_options (struct)`
 pub type NcFdPlaneOptions = crate::bindings::ffi::ncfdplane_options;
 
-/// Alignment within a plane or terminal.
-/// Left/right-justified, or centered.
-pub type NcAlign = crate::bindings::ffi::ncalign_e;
-
-/// Left alignment within an [`NcPlane`] or terminal.
-pub const NCALIGN_LEFT: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_LEFT;
-
-/// Right alignment within an [`NcPlane`] or terminal.
-pub const NCALIGN_RIGHT: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_RIGHT;
-
-/// Center alignment within an [`NcPlane`] or terminal.
-pub const NCALIGN_CENTER: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_CENTER;
-
-/// Do not align an [`NcPlane`] or terminal.
-pub const NCALIGN_UNALIGNED: NcAlign = crate::bindings::ffi::ncalign_e_NCALIGN_UNALIGNED;
-
 /// Blitter Mode (`NCBLIT_*`)
 ///
 /// We never blit full blocks, but instead spaces (more efficient) with the
@@ -293,4 +296,6 @@ pub const NCBLIT_BRAILLE: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_B
 pub const NCBLIT_DEFAULT: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_DEFAULT;
 
 /// [`NcBlitter`] mode (not yet implemented)
+///
+/// See [Sixel in Wikipedia](https://en.wikipedia.org/wiki/Sixel).
 pub const NCBLIT_SIXEL: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_SIXEL;
