@@ -33,22 +33,22 @@ mathplane(struct notcurses* nc){
   ncplane_set_fg_rgb(n, 0xd4af37); // metallic gold
   ncplane_set_bg_rgb(n, 0x0);
   if(n){
-    ncplane_printf_aligned(n, 0, NCALIGN_RIGHT, "∮E⋅da=Q,n→∞,∑f(i)=∏g(i)╭╭╭       ╮╮╮");
-    ncplane_printf_aligned(n, 1, NCALIGN_RIGHT, "│││ 8πG   │││");
-    ncplane_printf_aligned(n, 2, NCALIGN_RIGHT, "∀x∈ℝ:⌈x⌉=−⌊−x⌋,α∧¬β=¬(¬α∨β)│││ ───Tμν│││");
-    ncplane_printf_aligned(n, 3, NCALIGN_RIGHT, "│││  c⁴   │││");
-    ncplane_printf_aligned(n, 4, NCALIGN_RIGHT, "ℕ⊆ℕ₀⊂ℤ⊂ℚ⊂ℝ⊂ℂ(z̄=ℜ(z)−ℑ(z)⋅𝑖)⎨││       ││⎬");
-    ncplane_printf_aligned(n, 5, NCALIGN_RIGHT, "│││ ∞     │││");
-    ncplane_printf_aligned(n, 6, NCALIGN_RIGHT, "⊥<a≠b≡c≤d≪⊤⇒(⟦A⟧⇔⟪B⟫)│││ ⎲     │││");
-    ncplane_printf_aligned(n, 7, NCALIGN_RIGHT, "│││ ⎳aⁱ-bⁱ│││");
-    ncplane_printf_aligned(n, 8, NCALIGN_RIGHT, "2H₂+O₂⇌2H₂O,R=4.7kΩ,⌀200µm╰╰╰i=1    ╯╯╯");
+    ncplane_printf_aligned(n, 0, NCALIGN_RIGHT, "∮E⋅da=Q,n→∞,∑f(i)=∏g(i)⎧⎡⎛       ⎞⎤⎫");
+    ncplane_printf_aligned(n, 1, NCALIGN_RIGHT, "⎪⎢⎜ 8πG   ⎟⎥⎪");
+    ncplane_printf_aligned(n, 2, NCALIGN_RIGHT, "∀x∈ℝ:⌈x⌉=−⌊−x⌋,α∧¬β=¬(¬α∨β)⎪⎢⎜ ───Tμν⎟⎥⎪");
+    ncplane_printf_aligned(n, 3, NCALIGN_RIGHT, "⎪⎢⎜  c⁴   ⎟⎥⎪");
+    ncplane_printf_aligned(n, 4, NCALIGN_RIGHT, "ℕ⊆ℕ₀⊂ℤ⊂ℚ⊂ℝ⊂ℂ(z̄=ℜ(z)−ℑ(z)⋅𝑖)⎨⎢⎜       ⎟⎥⎬");
+    ncplane_printf_aligned(n, 5, NCALIGN_RIGHT, "⎪⎢⎜ ∞     ⎟⎥⎪");
+    ncplane_printf_aligned(n, 6, NCALIGN_RIGHT, "⊥<a≠b≡c≤d≪⊤⇒(⟦A⟧⇔⟪B⟫)⎪⎢⎜ ⎲     ⎟⎥⎪");
+    ncplane_printf_aligned(n, 7, NCALIGN_RIGHT, "⎪⎢⎜ ⎳aⁱ-bⁱ⎟⎥⎪");
+    ncplane_printf_aligned(n, 8, NCALIGN_RIGHT, "2H₂+O₂⇌2H₂O,R=4.7kΩ,⌀200µm⎩⎣⎝i=1    ⎠⎦⎭");
   }
   return n;
 }
 
 // the closer the coordinate is (lower distance), the more we lighten the cell
 static inline int
-lighten(struct ncplane* n, cell* c, int distance, int y, int x){
+lighten(struct ncplane* n, nccell* c, int distance, int y, int x){
   if(cell_wide_right_p(c)){ // not really a character
     return 0;
   }
@@ -62,14 +62,14 @@ lighten(struct ncplane* n, cell* c, int distance, int y, int x){
 }
 
 static inline int
-lightup_surrounding_cells(struct ncplane* n, cell* lightup, int y, int x){
+lightup_surrounding_cells(struct ncplane* n, nccell* lightup, int y, int x){
   lighten(n, lightup, 0, y, x);
   cell_release(n, lightup);
   return 0;
 }
 
 typedef struct worm {
-  cell lightup;
+  nccell lightup;
   int x, y;
   int prevx, prevy;
 } worm;
@@ -184,7 +184,7 @@ message(struct ncplane* n, int maxy, int maxx, int num, int total,
   ncplane_putegc_yx(n, 4, 17, "┬", NULL);
   ncplane_putegc_yx(n, 5, 17, "│", NULL);
   ncplane_putegc_yx(n, 6, 17, "╰", NULL);
-  cell hl = CELL_TRIVIAL_INITIALIZER;
+  nccell hl = CELL_TRIVIAL_INITIALIZER;
   cell_load(n, &hl, "─");
   cell_set_fg_rgb8(&hl, 255, 255, 255);
   cell_set_bg_rgb8(&hl, 32, 64, 32);
@@ -459,7 +459,7 @@ int witherworm_demo(struct notcurses* nc){
   ncplane_erase(n);
   for(i = 0 ; i < screens ; ++i){
     wchar_t key = NCKEY_INVALID;
-    cell c;
+    nccell c;
     struct timespec screenend;
     clock_gettime(CLOCK_MONOTONIC, &screenend);
     ns_to_timespec(timespec_to_ns(&screenend) + timespec_to_ns(&demodelay), &screenend);
