@@ -231,7 +231,7 @@ detect_cursor_inversion(ncdirect* n, int rows, int cols, int* y, int* x){
       return -1;
     }
   }
-  if(fflush(n->ttyfp) == EOF){
+  if(ncdirect_flush(n)){
     return -1;
   }
   int newy, newx;
@@ -367,12 +367,13 @@ ncdirect_align(const struct ncdirect* n, ncalign_e align, int c){
 
 static int
 ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
-  const int totx = ncdirect_dim_x(n);
   const int toty = ncdirect_dim_y(n);
   int dimy, dimx;
   ncplane_dim_yx(np, &dimy, &dimx);
 //fprintf(stderr, "rasterizing %dx%d+%d\n", dimy, dimx, xoff);
-  assert(dimx + xoff <= totx);
+  // save the existing style and colors
+  bool fgdefault = n->fgdefault, bgdefault = n->bgdefault;
+  uint32_t fgrgb = n->fgrgb, bgrgb = n->bgrgb;
   for(int y = 0 ; y < dimy ; ++y){
     if(xoff){
       if(ncdirect_cursor_move_yx(n, -1, xoff)){
@@ -386,8 +387,16 @@ ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
       if(egc == nullptr){
         return -1;
       }
-      ncdirect_fg_rgb(n, channels_fg_rgb(channels));
-      ncdirect_bg_rgb(n, channels_bg_rgb(channels));
+      if(channels_fg_alpha(channels) == CELL_ALPHA_TRANSPARENT){
+        ncdirect_fg_default(n);
+      }else{
+        ncdirect_fg_rgb(n, channels_fg_rgb(channels));
+      }
+      if(channels_bg_alpha(channels) == CELL_ALPHA_TRANSPARENT){
+        ncdirect_bg_default(n);
+      }else{
+        ncdirect_bg_rgb(n, channels_bg_rgb(channels));
+      }
 //fprintf(stderr, "%03d/%03d [%s] (%03dx%03d)\n", y, x, egc, dimy, dimx);
       if(fprintf(n->ttyfp, "%s", strlen(egc) == 0 ? " " : egc) < 0){
         free(egc);
@@ -395,11 +404,14 @@ ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
       }
       free(egc);
     }
-    if(dimx < totx){
-      ncdirect_bg_default(n);
-      if(putc('\n', n->ttyfp) == EOF){
-        return -1;
-      }
+    // yes, we want to reset colors and emit an explicit new line following
+    // each line of output; this is necessary if our output is lifted out and
+    // used in something e.g. paste(1).
+    // FIXME replace with a SGR clear
+    ncdirect_fg_default(n);
+    ncdirect_bg_default(n);
+    if(putc('\n', n->ttyfp) == EOF){
+      return -1;
     }
     if(y == toty){
       if(ncdirect_cursor_down(n, 1)){
@@ -407,32 +419,62 @@ ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
       }
     }
   }
+  // restore the previous colors
+  if(fgdefault){
+    ncdirect_fg_default(n);
+  }else{
+    ncdirect_fg_rgb(n, fgrgb);
+  }
+  if(bgdefault){
+    ncdirect_bg_default(n);
+  }else{
+    ncdirect_bg_rgb(n, bgrgb);
+  }
   return 0;
 }
 
-int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
+int ncdirect_raster_frame(ncdirect* n, ncdirectv* faken, ncalign_e align,
                           ncblitter_e blitter, ncscale_e scale){
+  auto bset = rgba_blitter_low(n->utf8, n->tcache.sextants, scale, true, blitter);
+  if(!bset){
+    free_plane(faken);
+    return -1;
+  }
+  int lenx = ncplane_dim_x(faken);
+  int xoff = ncdirect_align(n, align, lenx);
+  if(ncdirect_dump_plane(n, faken, xoff)){
+    free_plane(faken);
+    return -1;
+  }
+  int r = ncdirect_flush(n);
+  free_plane(faken);
+  return r;
+}
+
+ncdirectv* ncdirect_render_frame(ncdirect* n, const char* file,
+                                 ncblitter_e blitter, ncscale_e scale){
   struct ncvisual* ncv = ncvisual_from_file(file);
   if(ncv == nullptr){
-    return -1;
+    return nullptr;
   }
 //fprintf(stderr, "OUR DATA: %p rows/cols: %d/%d\n", ncv->data, ncv->rows, ncv->cols);
   int leny = ncv->rows; // we allow it to freely scroll
   int lenx = ncv->cols;
   if(leny == 0 || lenx == 0){
     ncvisual_destroy(ncv);
-    return -1;
+    return nullptr;
   }
 //fprintf(stderr, "render %d/%d to %d+%dx%d scaling: %d\n", ncv->rows, ncv->cols, leny, lenx, scale);
-  auto bset = rgba_blitter_low(n->utf8, scale, true, blitter);
+  auto bset = rgba_blitter_low(n->utf8, n->tcache.sextants, scale, true, blitter);
   if(!bset){
-    return -1;
+    ncvisual_destroy(ncv);
+    return nullptr;
   }
   int disprows, dispcols;
-  if(scale != NCSCALE_NONE){
+  if(scale != NCSCALE_NONE && scale != NCSCALE_NONE_HIRES){
     dispcols = ncdirect_dim_x(n) * encoding_x_scale(bset);
     disprows = ncdirect_dim_y(n) * encoding_y_scale(bset);
-    if(scale == NCSCALE_SCALE){
+    if(scale == NCSCALE_SCALE || scale == NCSCALE_SCALE_HIRES){
       scale_visual(ncv, &disprows, &dispcols);
     }
   }else{
@@ -448,32 +490,32 @@ int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
     .rows = disprows / encoding_y_scale(bset),
     .cols = dispcols / encoding_x_scale(bset),
     .userptr = nullptr,
-    .name = "direct",
+    .name = "fake",
     .resizecb = nullptr,
     .flags = 0,
   };
   struct ncplane* faken = ncplane_new_internal(nullptr, nullptr, &nopts);
   if(faken == nullptr){
-    return -1;
+    ncvisual_destroy(ncv);
+    return nullptr;
   }
   if(ncvisual_blit(ncv, disprows, dispcols, faken, bset,
                    0, 0, 0, 0, leny, lenx, false)){
     ncvisual_destroy(ncv);
     free_plane(faken);
-    return -1;
+    return nullptr;
   }
   ncvisual_destroy(ncv);
-  int xoff = ncdirect_align(n, align, lenx / encoding_x_scale(bset));
-  if(ncdirect_dump_plane(n, faken, xoff)){
+  return faken;
+}
+
+int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
+                          ncblitter_e blitter, ncscale_e scale){
+  auto faken = ncdirect_render_frame(n, file, blitter, scale);
+  if(!faken){
     return -1;
   }
-  ncdirect_fg_default(n);
-  ncdirect_bg_default(n);
-  while(fflush(stdout) == EOF && errno == EAGAIN){
-    ;
-  }
-  free_plane(faken);
-  return 0;
+  return ncdirect_raster_frame(n, faken, align, blitter, scale);
 }
 
 int ncdirect_fg_palindex(ncdirect* nc, int pidx){
@@ -561,15 +603,17 @@ ncdirect* ncdirect_init(const char* termtype, FILE* outfp, uint64_t flags){
   if(ncinputlayer_init(&ret->input, stdin)){
     goto err;
   }
+  const char* shortname_term;
   int termerr;
   if(setupterm(termtype, ret->ctermfd, &termerr) != OK){
     fprintf(stderr, "Terminfo error %d (see terminfo(3ncurses))\n", termerr);
     goto err;
   }
+  shortname_term = termname();
   if(ncvisual_init(ffmpeg_log_level(NCLOGLEVEL_SILENT))){
     goto err;
   }
-  if(interrogate_terminfo(&ret->tcache)){
+  if(interrogate_terminfo(&ret->tcache, shortname_term)){
     goto err;
   }
   ret->fgdefault = ret->bgdefault = true;
@@ -615,18 +659,20 @@ int ncdirect_stop(ncdirect* nc){
 }
 
 static inline int
-ncdirect_style_emit(ncdirect* n, const char* sgr, unsigned stylebits, FILE* out){
-  if(sgr == nullptr){
-    return -1;
+ncdirect_style_emit(ncdirect* n, unsigned stylebits, FILE* out){
+  int r = -1;
+  if(stylebits == 0 && n->tcache.sgr0){
+    r = term_emit("sgr0", n->tcache.sgr0, n->ttyfp, false);
+  }else if(n->tcache.sgr){
+    r = term_emit("sgr", tiparm(n->tcache.sgr, stylebits & NCSTYLE_STANDOUT,
+                                stylebits & NCSTYLE_UNDERLINE,
+                                stylebits & NCSTYLE_REVERSE,
+                                stylebits & NCSTYLE_BLINK,
+                                stylebits & NCSTYLE_DIM,
+                                stylebits & NCSTYLE_BOLD,
+                                stylebits & NCSTYLE_INVIS,
+                                stylebits & NCSTYLE_PROTECT, 0), out, false);
   }
-  int r = term_emit("sgr", tiparm(sgr, stylebits & NCSTYLE_STANDOUT,
-                                  stylebits & NCSTYLE_UNDERLINE,
-                                  stylebits & NCSTYLE_REVERSE,
-                                  stylebits & NCSTYLE_BLINK,
-                                  stylebits & NCSTYLE_DIM,
-                                  stylebits & NCSTYLE_BOLD,
-                                  stylebits & NCSTYLE_INVIS,
-                                  stylebits & NCSTYLE_PROTECT, 0), out, false);
   // sgr resets colors, so set them back up if not defaults
   if(r == 0){
     if(!n->fgdefault){
@@ -641,7 +687,7 @@ ncdirect_style_emit(ncdirect* n, const char* sgr, unsigned stylebits, FILE* out)
 
 int ncdirect_styles_on(ncdirect* n, unsigned stylebits){
   uint32_t stylemask = n->stylemask | stylebits;
-  if(ncdirect_style_emit(n, n->tcache.sgr, stylemask, n->ttyfp) == 0){
+  if(ncdirect_style_emit(n, stylemask, n->ttyfp) == 0){
     if(term_setstyle(n->ttyfp, n->stylemask, stylemask, NCSTYLE_ITALIC,
                      n->tcache.italics, n->tcache.italoff)){
       return 0;
@@ -659,7 +705,7 @@ int ncdirect_styles_on(ncdirect* n, unsigned stylebits){
 // turn off any specified stylebits
 int ncdirect_styles_off(ncdirect* n, unsigned stylebits){
   uint32_t stylemask = n->stylemask & ~stylebits;
-  if(ncdirect_style_emit(n, n->tcache.sgr, stylemask, n->ttyfp) == 0){
+  if(ncdirect_style_emit(n, stylemask, n->ttyfp) == 0){
     if(term_setstyle(n->ttyfp, n->stylemask, stylemask, NCSTYLE_ITALIC,
                      n->tcache.italics, n->tcache.italoff)){
       return -1;
@@ -677,7 +723,7 @@ int ncdirect_styles_off(ncdirect* n, unsigned stylebits){
 // set the current stylebits to exactly those provided
 int ncdirect_styles_set(ncdirect* n, unsigned stylebits){
   uint32_t stylemask = stylebits;
-  if(ncdirect_style_emit(n, n->tcache.sgr, stylemask, n->ttyfp) == 0){
+  if(ncdirect_style_emit(n, stylemask, n->ttyfp) == 0){
     n->stylemask &= !(NCSTYLE_ITALIC | NCSTYLE_STRUCK); // sgr clears both
     if(term_setstyle(n->ttyfp, n->stylemask, stylemask, NCSTYLE_ITALIC,
                      n->tcache.italics, n->tcache.italoff)){
@@ -955,8 +1001,11 @@ bool ncdirect_canutf8(const ncdirect* n){
 }
 
 int ncdirect_flush(const ncdirect* nc){
-  if(fflush(nc->ttyfp) == EOF){
-    return -1;
+  int r;
+  while((r = fflush(nc->ttyfp)) == EOF){
+    if(errno != EAGAIN){
+      return -1;
+    }
   }
   return 0;
 }
