@@ -95,8 +95,6 @@ typedef struct ncplane {
   bool scrolling;        // is scrolling enabled? always disabled by default
 } ncplane;
 
-#include "blitset.h"
-
 // current presentation state of the terminal. it is carried across render
 // instances. initialize everything to 0 on a terminal reset / startup.
 typedef struct rasterstate {
@@ -119,14 +117,13 @@ typedef struct rasterstate {
   unsigned lastbr; // background rgb, overloaded for palindexed bg
   unsigned lastbg;
   unsigned lastbb;
-  // we can elide a color escape iff the color has not changed between the two
-  // cells and the current cell uses no defaults, or if both the current and
-  // the last used both defaults.
+  // we elide a color escape iff the color has not changed between two cells
   bool fgelidable;
   bool bgelidable;
   bool fgpalelidable;
   bool bgpalelidable;
-  bool defaultelidable;
+  bool fgdefelidable;
+  bool bgdefelidable;
 } rasterstate;
 
 // Tablets are the toplevel entitites within an ncreel. Each corresponds to
@@ -236,6 +233,8 @@ typedef struct tinfo {
   char* setaf;    // set foreground color (ANSI)
   char* setab;    // set background color (ANSI)
   char* op;       // set foreground and background color to default
+  char* fgop;     // set foreground to default
+  char* bgop;     // set background to default
   char* cup;      // move cursor
   char* cuu;      // move N cells up
   char* cub;      // move N cells left
@@ -274,6 +273,13 @@ typedef struct tinfo {
   bool AMflag;    // "AM" flag for automatic movement to next line
   char* smcup;    // enter alternate mode
   char* rmcup;    // restore primary mode
+
+  // kitty interprets an RGB background that matches the default background
+  // color *as* the default background, meaning it'll be translucent if
+  // background_opaque is in use. detect this, and avoid the default if so.
+  // bg_collides_default is either 0x0000000 or 0x1RRGGBB.
+  uint32_t bg_collides_default;
+  bool sextants;  // do we have Unicode 13 sextant support?
 } tinfo;
 
 typedef struct ncinputlayer {
@@ -360,11 +366,16 @@ typedef struct notcurses {
   bool libsixel;  // do we have Sixel support?
 } notcurses;
 
+#include "blitset.h"
+
 void sigwinch_handler(int signo);
 
 void init_lang(notcurses* nc); // nc may be NULL, only used for logging
 int terminfostr(char** gseq, const char* name);
-int interrogate_terminfo(tinfo* ti);
+int interrogate_terminfo(tinfo* ti, const char* termname);
+
+// if there were missing elements we wanted from terminfo, bitch about them here
+void warn_terminfo(const notcurses* nc, const tinfo* ti);
 
 int resize_callbacks_children(ncplane* n);
 
