@@ -93,8 +93,8 @@ notcurses_stop_minimal(notcurses* nc){
   return ret;
 }
 
-// this wildly unsafe handler will attempt to restore the screen upon
-// reception of SIG{INT, SEGV, ABRT, QUIT, TERM}. godspeed you, black emperor!
+// this wildly unsafe handler will attempt to restore the screen upon receipt
+// of SIG{INT, SEGV, ABRT, QUIT, TERM}. godspeed you, black emperor!
 static void
 fatal_handler(int signo){
   notcurses* nc = atomic_load(&signal_nc);
@@ -219,20 +219,32 @@ cursor_invalid_p(const ncplane* n){
 }
 
 char* ncplane_at_cursor(ncplane* n, uint16_t* stylemask, uint64_t* channels){
-  if(cursor_invalid_p(n)){
-    return NULL;
-  }
-  return cell_extract(n, &n->fb[nfbcellidx(n, n->y, n->x)], stylemask, channels);
+  return ncplane_at_yx(n, n->y, n->x, stylemask, channels);
 }
 
 char* ncplane_at_yx(const ncplane* n, int y, int x, uint16_t* stylemask, uint64_t* channels){
-  char* ret = NULL;
   if(y < n->leny && x < n->lenx){
     if(y >= 0 && x >= 0){
-      ret = cell_extract(n, &n->fb[nfbcellidx(n, y, x)], stylemask, channels);
+      return cell_extract(n, &n->fb[nfbcellidx(n, y, x)], stylemask, channels);
     }
   }
-  return ret;
+  return NULL;
+}
+
+int ncplane_at_cursor_cell(ncplane* n, nccell* c){
+  return ncplane_at_yx_cell(n, n->y, n->x, c);
+}
+
+int ncplane_at_yx_cell(ncplane* n, int y, int x, nccell* c){
+  if(y < n->leny && x < n->lenx){
+    if(y >= 0 && x >= 0){
+      nccell* targ = ncplane_cell_ref_yx(n, y, x);
+      if(cell_duplicate(n, c, targ) == 0){
+        return strlen(cell_extended_gcluster(n, targ));
+      }
+    }
+  }
+  return -1;
 }
 
 void ncplane_dim_yx(const ncplane* n, int* rows, int* cols){
@@ -957,24 +969,6 @@ get_tty_fd(notcurses* nc, FILE* ttyfp){
   return fd;
 }
 
-int cbreak_mode(int ttyfd, const struct termios* tpreserved){
-  // assume it's not a true terminal (e.g. we might be redirected to a file)
-  struct termios modtermios;
-  memcpy(&modtermios, tpreserved, sizeof(modtermios));
-  // see termios(3). disabling ECHO and ICANON means input will not be echoed
-  // to the screen, input is made available without enter-based buffering, and
-  // line editing is disabled. since we have not gone into raw mode, ctrl+c
-  // etc. still have their typical effects. ICRNL maps return to 13 (Ctrl+M)
-  // instead of 10 (Ctrl+J).
-  modtermios.c_lflag &= (~ECHO & ~ICANON);
-  modtermios.c_iflag &= (~ICRNL);
-  if(tcsetattr(ttyfd, TCSANOW, &modtermios)){
-    fprintf(stderr, "Error disabling echo / canonical on %d (%s)\n", ttyfd, strerror(errno));
-    return -1;
-  }
-  return 0;
-}
-
 int ncinputlayer_init(ncinputlayer* nilayer, FILE* infp){
   setbuffer(infp, NULL, 0);
   nilayer->inputescapes = NULL;
@@ -1115,9 +1109,10 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
             shortname_term ? shortname_term : "?",
             longname_term ? longname_term : "?");
   }
-  if(interrogate_terminfo(&ret->tcache)){
+  if(interrogate_terminfo(&ret->tcache, shortname_term)){
     goto err;
   }
+  warn_terminfo(ret, &ret->tcache);
   reset_term_attributes(ret);
   if(ncinputlayer_init(&ret->input, stdin)){
     goto err;
@@ -1187,16 +1182,25 @@ err:
 // updates *pile to point at (*pile)->next, frees all but standard pile/plane
 static void
 ncpile_drop(notcurses* nc, ncpile** pile){
+  bool sawstdplane = false;
   ncpile* next = (*pile)->next;
   ncplane* p = (*pile)->top;
   while(p){
     ncplane* tmp = p->below;
     if(nc->stdplane != p){
       free_plane(p);
+    }else{
+      sawstdplane = true;
     }
     p = tmp;
   }
   *pile = next;
+  if(sawstdplane){
+    ncplane_pile(nc->stdplane)->top = nc->stdplane;
+    ncplane_pile(nc->stdplane)->bottom = nc->stdplane;
+    nc->stdplane->above = nc->stdplane->below = NULL;
+    nc->stdplane->blist = NULL;
+  }
 }
 
 // drop all piles and all planes, save the standard plane and its pile
@@ -1208,9 +1212,6 @@ void notcurses_drop_planes(notcurses* nc){
     ncpile_drop(nc, &p);
   }while(p0 != p);
   pthread_mutex_unlock(&nc->pilelock);
-  ncplane_pile(nc->stdplane)->top = nc->stdplane;
-  ncplane_pile(nc->stdplane)->bottom = nc->stdplane;
-  nc->stdplane->above = nc->stdplane->below = NULL;
 }
 
 int notcurses_stop(notcurses* nc){
@@ -2110,6 +2111,10 @@ bool notcurses_canutf8(const notcurses* nc){
   return nc->utf8;
 }
 
+bool notcurses_cansextant(const notcurses* nc){
+  return nc->tcache.sextants && nc->utf8;
+}
+
 bool notcurses_canfade(const notcurses* nc){
   return nc->tcache.CCCflag || nc->tcache.RGBflag;
 }
@@ -2402,6 +2407,10 @@ lex_long(const char* op, int* i, char** endptr){
 int notcurses_lex_scalemode(const char* op, ncscale_e* scalemode){
   if(strcasecmp(op, "stretch") == 0){
     *scalemode = NCSCALE_STRETCH;
+  }else if(strcasecmp(op, "scalehi") == 0){
+    *scalemode = NCSCALE_SCALE_HIRES;
+  }else if(strcasecmp(op, "hires") == 0){
+    *scalemode = NCSCALE_NONE_HIRES;
   }else if(strcasecmp(op, "scale") == 0){
     *scalemode = NCSCALE_SCALE;
   }else if(strcasecmp(op, "none") == 0){
@@ -2419,6 +2428,10 @@ const char* notcurses_str_scalemode(ncscale_e scalemode){
     return "scale";
   }else if(scalemode == NCSCALE_NONE){
     return "none";
+  }else if(scalemode == NCSCALE_NONE_HIRES){
+    return "hires";
+  }else if(scalemode == NCSCALE_SCALE_HIRES){
+    return "scalehi";
   }
   return NULL;
 }
