@@ -651,13 +651,20 @@ term_esc_rgb(FILE* out, bool foreground, unsigned r, unsigned g, unsigned b){
 
 static inline int
 term_bg_rgb8(bool RGBflag, const char* setab, int colors, FILE* out,
-             unsigned r, unsigned g, unsigned b){
+             unsigned r, unsigned g, unsigned b, uint32_t bg_collides_default){
   // We typically want to use tputs() and tiperm() to acquire and write the
   // escapes, as these take into account terminal-specific delays, padding,
   // etc. For the case of DirectColor, there is no suitable terminfo entry, but
   // we're also in that case working with hopefully more robust terminals.
   // If it doesn't work, eh, it doesn't work. Fuck the world; save yourself.
   if(RGBflag){
+    if(bg_collides_default){
+      if((r == (bg_collides_default & 0xff0000lu)) &&
+         (g == (bg_collides_default & 0xff00lu)) &&
+         (b == (bg_collides_default & 0xfflu))){
+        ++b; // what if it's 255 FIXME
+      }
+    }
     return term_esc_rgb(out, false, r, g, b);
   }else{
     if(setab == NULL){
@@ -724,31 +731,30 @@ update_palette(notcurses* nc, FILE* out){
 }
 
 // sync the drawing position to the specified location with as little overhead
-// as possible (with nothing, if already at the right location).
+// as possible (with nothing, if already at the right location). we prefer
+// absolute horizontal moves (hpa) to relative ones, in the rare event that
+// our understanding of our horizontal location is faulty.
 // FIXME fall back to synthesized moves in the absence of capabilities (i.e.
 // textronix lacks cup; fake it with horiz+vert moves)
 static inline int
 goto_location(notcurses* nc, FILE* out, int y, int x){
   int ret = 0;
-  if(nc->rstate.y == y){ // only need move x
-    const int xdiff = x - nc->rstate.x;
-    if(xdiff > 0){
-      if(xdiff == 1 && nc->tcache.cuf1){
-        ret = term_emit("cuf1", tiparm(nc->tcache.cuf1), out, false);
-        nc->rstate.x = x;
-        return ret;
-      }else if(nc->tcache.cuf){
-        ret = term_emit("cuf", tiparm(nc->tcache.cuf, xdiff), out, false);
-        nc->rstate.x = x;
-        return ret;
-      }
-    }else if(xdiff == 0){
-      return 0; // no move needed
+  // if we don't have hpa, force a cup even if we're only 1 char away. the only
+  // terminal i know supporting cup sans hpa is vt100, and vt100 can suck it.
+  // you can't use cuf for backwards moves anyway; again, vt100 can suck it.
+  if(nc->rstate.y == y && nc->tcache.hpa){ // only need move x
+    if(nc->rstate.x == x){ // needn't move shit
+      return 0;
     }
-    // cub1/cub tend to be destructive in my experiments :/
+    if(x == nc->rstate.x + 1 && nc->tcache.cuf1){
+      ret = term_emit("cuf1", tiparm(nc->tcache.cuf1), out, false);
+    }else{
+      ret = term_emit("hpa", tiparm(nc->tcache.hpa, x), out, false);
+    }
+  }else{
+    // cup is required, no need to check for existence
+    ret = term_emit("cup", tiparm(nc->tcache.cup, y, x), out, false);
   }
-  // cup is required, no need to check for existence
-  ret = term_emit("cup", tiparm(nc->tcache.cup, y, x), out, false);
   if(ret == 0){
     nc->rstate.x = x;
     nc->rstate.y = y;
@@ -756,6 +762,47 @@ goto_location(notcurses* nc, FILE* out, int y, int x){
   return ret;
 }
 
+// at least one of the foreground and background are the default. emit the
+// necessary return to default (if one is necessary), and update rstate.
+static inline int
+raster_defaults(notcurses* nc, bool fgdef, bool bgdef, FILE* out){
+  if(!nc->tcache.op){ // if we don't have op, we don't have fgop/bgop
+    return 0;
+  }
+  bool mustsetfg = fgdef && !nc->rstate.fgdefelidable;
+  bool mustsetbg = bgdef && !nc->rstate.bgdefelidable;
+  if(!mustsetfg && !mustsetbg){ // don't need emit anything
+    ++nc->stats.defaultelisions;
+    return 0;
+  }else if((mustsetfg && mustsetbg) || !nc->tcache.fgop){
+    if(term_emit("op", nc->tcache.op, out, false)){
+      return -1;
+    }
+    nc->rstate.fgdefelidable = true;
+    nc->rstate.bgdefelidable = true;
+    nc->rstate.fgelidable = false;
+    nc->rstate.bgelidable = false;
+    nc->rstate.fgpalelidable = false;
+    nc->rstate.bgpalelidable = false;
+  }else if(mustsetfg){
+    if(term_emit("fgop", nc->tcache.fgop, out, false)){
+      return -1;
+    }
+    nc->rstate.fgdefelidable = true;
+    nc->rstate.fgelidable = false;
+    nc->rstate.fgpalelidable = false;
+  }else{
+    if(term_emit("bgop", nc->tcache.bgop, out, false)){
+      return -1;
+    }
+    nc->rstate.bgdefelidable = true;
+    nc->rstate.bgelidable = false;
+    nc->rstate.bgpalelidable = false;
+  }
+  ++nc->stats.defaultemissions;
+  return 0;
+}
+
 // Producing the frame requires three steps:
 //  * render -- build up a flat framebuffer from a set of ncplanes
 //  * rasterize -- build up a UTF-8/ASCII stream of escapes and EGCs
@@ -808,7 +855,8 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
           return -1;
         }
         if(normalized){
-          nc->rstate.defaultelidable = true;
+          nc->rstate.fgdefelidable = true;
+          nc->rstate.bgdefelidable = true;
           nc->rstate.bgelidable = false;
           nc->rstate.fgelidable = false;
           nc->rstate.bgpalelidable = false;
@@ -826,22 +874,10 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
         //  * we are a no-background glyph, and the previous was default foreground
         bool nobackground = cell_nobackground_p(srccell);
         if((cell_fg_default_p(srccell)) || (!nobackground && cell_bg_default_p(srccell))){
-          if(!nc->rstate.defaultelidable){
-            ++nc->stats.defaultemissions;
-            if(nc->tcache.op){
-              if(term_emit("op", nc->tcache.op, out, false)){
-                return -1;
-              }
-            }
-          }else{
-            ++nc->stats.defaultelisions;
+          if(raster_defaults(nc, cell_fg_default_p(srccell),
+                             !nobackground && cell_bg_default_p(srccell), out)){
+            return -1;
           }
-          // if either is not default, this will get turned off
-          nc->rstate.defaultelidable = true;
-          nc->rstate.fgelidable = false;
-          nc->rstate.bgelidable = false;
-          nc->rstate.fgpalelidable = false;
-          nc->rstate.bgpalelidable = false;
         }
         // if our cell has a non-default foreground, we can elide the non-default
         // foreground set iff either:
@@ -860,7 +896,7 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
             nc->rstate.fgpalelidable = true;
           }
           nc->rstate.lastr = palfg;
-          nc->rstate.defaultelidable = false;
+          nc->rstate.fgdefelidable = false;
           nc->rstate.fgelidable = false;
         }else if(!cell_fg_default_p(srccell)){ // rgb foreground
           cell_fg_rgb8(srccell, &r, &g, &b);
@@ -874,7 +910,7 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
             nc->rstate.fgelidable = true;
           }
           nc->rstate.lastr = r; nc->rstate.lastg = g; nc->rstate.lastb = b;
-          nc->rstate.defaultelidable = false;
+          nc->rstate.fgdefelidable = false;
           nc->rstate.fgpalelidable = false;
         }
         if(nobackground){
@@ -891,21 +927,23 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
             nc->rstate.bgpalelidable = true;
           }
           nc->rstate.lastr = palbg;
-          nc->rstate.defaultelidable = false;
+          nc->rstate.bgdefelidable = false;
           nc->rstate.bgelidable = false;
         }else if(!cell_bg_default_p(srccell)){ // rgb background
           cell_bg_rgb8(srccell, &br, &bg, &bb);
           if(nc->rstate.bgelidable && nc->rstate.lastbr == br && nc->rstate.lastbg == bg && nc->rstate.lastbb == bb){
             ++nc->stats.bgelisions;
           }else{
-            if(term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab, nc->tcache.colors, out, br, bg, bb)){
+            if(term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab,
+                            nc->tcache.colors, out, br, bg, bb,
+                            nc->tcache.bg_collides_default)){
               return -1;
             }
             ++nc->stats.bgemissions;
             nc->rstate.bgelidable = true;
           }
           nc->rstate.lastbr = br; nc->rstate.lastbg = bg; nc->rstate.lastbb = bb;
-          nc->rstate.defaultelidable = false;
+          nc->rstate.bgdefelidable = false;
           nc->rstate.bgpalelidable = false;
         }
 //fprintf(stderr, "RAST %08x [%s] to %d/%d cols: %u %016lx\n", srccell->gcluster, pool_extended_gcluster(&nc->pool, srccell), y, x, srccell->width + 1, srccell->channels);
@@ -1194,7 +1232,8 @@ int ncdirect_bg_rgb(ncdirect* nc, unsigned rgb){
     return -1;
   }
   if(term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab, nc->tcache.colors, nc->ttyfp,
-                  (rgb & 0xff0000u) >> 16u, (rgb & 0xff00u) >> 8u, rgb & 0xffu)){
+                  (rgb & 0xff0000u) >> 16u, (rgb & 0xff00u) >> 8u, rgb & 0xffu,
+                  nc->tcache.bg_collides_default)){
     return -1;
   }
   nc->bgdefault = false;
