@@ -17,13 +17,14 @@ static void usage(std::ostream& os, const char* name, int exitcode)
   __attribute__ ((noreturn));
 
 void usage(std::ostream& o, const char* name, int exitcode){
-  o << "usage: " << name << " [ -h ] [ -q ] [ -m margins ] [ -l loglevel ] [ -d mult ] [ -s scaletype ] [ -k ] [ -L ] files" << '\n';
+  o << "usage: " << name << " [ -h ] [ -q ] [ -m margins ] [ -l loglevel ] [ -d mult ] [ -s scaletype ] [ -k ] [ -L ] [ -t seconds ] files" << '\n';
   o << " -h: display help and exit with success\n";
   o << " -q: be quiet (no frame/timing information along top of screen)\n";
   o << " -k: don't use the alternate screen\n";
   o << " -L: loop frames\n";
+  o << " -t seconds: delay t seconds after each file\n";
   o << " -l loglevel: integer between 0 and 9, goes to stderr'\n";
-  o << " -s scaletype: one of 'none', 'scale', or 'stretch'\n";
+  o << " -s scaletype: one of 'none', 'hires', 'scale', 'scalehi', or 'stretch'\n";
   o << " -b blitter: 'ascii', 'halfblock', 'quadblitter', 'sexblitter', or 'braille'\n";
   o << " -m margins: margin, or 4 comma-separated margins\n";
   o << " -d mult: non-negative floating point scale for frame time" << std::endl;
@@ -73,7 +74,7 @@ auto perframe(struct ncvisual* ncv, struct ncvisual_options* vopts,
   intmax_t ns = timespec_to_ns(&now) - timespec_to_ns(start);
   marsh->blitter = vopts->blitter;
   if(marsh->blitter == NCBLIT_DEFAULT){
-    marsh->blitter = ncvisual_default_blitter(notcurses_canutf8(nc), vopts->scaling);
+    marsh->blitter = ncvisual_media_defblitter(nc, vopts->scaling);
   }
   if(!marsh->quiet){
     stdn->printf(0, NCAlign::Left, "frame %06d\u2026 (%s)", marsh->framecount,
@@ -172,12 +173,13 @@ auto perframe(struct ncvisual* ncv, struct ncvisual_options* vopts,
 // can exit() directly. returns index in argv of first non-option param.
 auto handle_opts(int argc, char** argv, notcurses_options& opts, bool* quiet,
                  float* timescale, ncscale_e* scalemode, ncblitter_e* blitter,
-                 bool* loop)
+                 float* displaytime, bool* loop)
                  -> int {
   *timescale = 1.0;
   *scalemode = NCSCALE_STRETCH;
+  *displaytime = -1;
   int c;
-  while((c = getopt(argc, argv, "hql:d:s:b:m:kL")) != -1){
+  while((c = getopt(argc, argv, "hql:d:s:b:t:m:kL")) != -1){
     switch(c){
       case 'h':
         usage(std::cout, argv[0], EXIT_SUCCESS);
@@ -187,7 +189,7 @@ auto handle_opts(int argc, char** argv, notcurses_options& opts, bool* quiet,
         break;
       case 's':
         if(notcurses_lex_scalemode(optarg, scalemode)){
-          std::cerr << "Scaling type should be one of stretch, scale, none (got "
+          std::cerr << "Scaling type should be one of stretch, scale, scalehi, hires, none (got "
                     << optarg << ")" << std::endl;
           usage(std::cerr, argv[0], EXIT_FAILURE);
         }
@@ -214,6 +216,17 @@ auto handle_opts(int argc, char** argv, notcurses_options& opts, bool* quiet,
           usage(std::cerr, argv[0], EXIT_FAILURE);
         }
         break;
+      }case 't':{
+        std::stringstream ss;
+        ss << optarg;
+        float ts;
+        ss >> ts;
+        if(ts < 0){
+          std::cerr << "Invalid displaytime [" << optarg << "] (wanted (0..))\n";
+          usage(std::cerr, argv[0], EXIT_FAILURE);
+        }
+        *displaytime = ts;
+        break;
       }case 'd':{
         std::stringstream ss;
         ss << optarg;
@@ -257,14 +270,14 @@ auto main(int argc, char** argv) -> int {
     std::cerr << "Couldn't set locale based off LANG\n";
     return EXIT_FAILURE;
   }
-  float timescale;
+  float timescale, displaytime;
   ncscale_e scalemode;
   notcurses_options ncopts{};
   ncblitter_e blitter = NCBLIT_DEFAULT;
   bool quiet = false;
   bool loop = false;
   auto nonopt = handle_opts(argc, argv, ncopts, &quiet, &timescale, &scalemode,
-                            &blitter, &loop);
+                            &blitter, &displaytime, &loop);
   ncopts.flags |= NCOPTION_INHIBIT_SETLOCALE;
   NotCurses nc{ncopts};
   if(!nc.can_open_images()){
@@ -307,26 +320,34 @@ auto main(int argc, char** argv) -> int {
         if(r == 0){
           vopts.blitter = marsh.blitter;
           if(!loop){
-            stdn->printf(0, NCAlign::Center, "press key to advance");
-            if(!nc.render()){
-              failed = true;
-              break;
-            }
-            char32_t ie = nc.getc(true);
-            if(ie == (char32_t)-1){
-              failed = true;
-              break;
-            }else if(ie == 'q'){
-              goto done;
-            }else if(ie >= '0' && ie <= '8'){
-              --i; // rerun same input with the new blitter
-              vopts.blitter = blitter = static_cast<ncblitter_e>(ie - '0');
-            }else if(ie == NCKey::Resize){
-              --i; // rerun with the new size
-              if(!nc.refresh(&dimy, &dimx)){
+            if(displaytime < 0){
+              stdn->printf(0, NCAlign::Center, "press key to advance");
+              if(!nc.render()){
                 failed = true;
                 break;
               }
+              char32_t ie = nc.getc(true);
+              if(ie == (char32_t)-1){
+                failed = true;
+                break;
+              }else if(ie == 'q'){
+                goto done;
+              }else if(ie >= '0' && ie <= '8'){
+                --i; // rerun same input with the new blitter
+                vopts.blitter = blitter = static_cast<ncblitter_e>(ie - '0');
+              }else if(ie == NCKey::Resize){
+                --i; // rerun with the new size
+                if(!nc.refresh(&dimy, &dimx)){
+                  failed = true;
+                  break;
+                }
+              }
+            }else{
+              // FIXME do we still want to honor keybindings when timing out?
+              struct timespec ts;
+              ts.tv_sec = displaytime;
+              ts.tv_nsec = (displaytime - ts.tv_sec) * NANOSECS_IN_SEC;
+              clock_nanosleep(CLOCK_MONOTONIC, 0, &ts, NULL);
             }
           }else{
             ncv->decode_loop();
